import { __extends } from "tslib";
import { CreateStackInstancesInput, CreateStackInstancesOutput } from "../models/models_0";
import { deserializeAws_queryCreateStackInstancesCommand, serializeAws_queryCreateStackInstancesCommand, } from "../protocols/Aws_query";
import { getSerdePlugin } from "@aws-sdk/middleware-serde";
import { Command as $Command } from "@aws-sdk/smithy-client";
/**
 * <p>Creates stack instances for the specified accounts, within the specified Regions. A
 *          stack instance refers to a stack in a specific account and Region. You must specify at least one value for either <code>Accounts</code> or <code>DeploymentTargets</code>, and you must specify at least one value for <code>Regions</code>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { CloudFormationClient, CreateStackInstancesCommand } from "@aws-sdk/client-cloudformation"; // ES Modules import
 * // const { CloudFormationClient, CreateStackInstancesCommand } = require("@aws-sdk/client-cloudformation"); // CommonJS import
 * const client = new CloudFormationClient(config);
 * const command = new CreateStackInstancesCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link CreateStackInstancesCommandInput} for command's `input` shape.
 * @see {@link CreateStackInstancesCommandOutput} for command's `response` shape.
 * @see {@link CloudFormationClientResolvedConfig | config} for command's `input` shape.
 *
 */
var CreateStackInstancesCommand = /** @class */ (function (_super) {
    __extends(CreateStackInstancesCommand, _super);
    // Start section: command_properties
    // End section: command_properties
    function CreateStackInstancesCommand(input) {
        var _this = 
        // Start section: command_constructor
        _super.call(this) || this;
        _this.input = input;
        return _this;
        // End section: command_constructor
    }
    /**
     * @internal
     */
    CreateStackInstancesCommand.prototype.resolveMiddleware = function (clientStack, configuration, options) {
        this.middlewareStack.use(getSerdePlugin(configuration, this.serialize, this.deserialize));
        var stack = clientStack.concat(this.middlewareStack);
        var logger = configuration.logger;
        var clientName = "CloudFormationClient";
        var commandName = "CreateStackInstancesCommand";
        var handlerExecutionContext = {
            logger: logger,
            clientName: clientName,
            commandName: commandName,
            inputFilterSensitiveLog: CreateStackInstancesInput.filterSensitiveLog,
            outputFilterSensitiveLog: CreateStackInstancesOutput.filterSensitiveLog,
        };
        var requestHandler = configuration.requestHandler;
        return stack.resolve(function (request) {
            return requestHandler.handle(request.request, options || {});
        }, handlerExecutionContext);
    };
    CreateStackInstancesCommand.prototype.serialize = function (input, context) {
        return serializeAws_queryCreateStackInstancesCommand(input, context);
    };
    CreateStackInstancesCommand.prototype.deserialize = function (output, context) {
        return deserializeAws_queryCreateStackInstancesCommand(output, context);
    };
    return CreateStackInstancesCommand;
}($Command));
export { CreateStackInstancesCommand };
//# sourceMappingURL=CreateStackInstancesCommand.js.map